summaryrefslogtreecommitdiffstats
path: root/src/plugins/generic/tuiotouch/qoscbundle_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/generic/tuiotouch/qoscbundle_p.h')
-rw-r--r--src/plugins/generic/tuiotouch/qoscbundle_p.h58
1 files changed, 11 insertions, 47 deletions
diff --git a/src/plugins/generic/tuiotouch/qoscbundle_p.h b/src/plugins/generic/tuiotouch/qoscbundle_p.h
index cb3ec4d251..8c4e37fa8f 100644
--- a/src/plugins/generic/tuiotouch/qoscbundle_p.h
+++ b/src/plugins/generic/tuiotouch/qoscbundle_p.h
@@ -1,49 +1,13 @@
-/****************************************************************************
-**
-** Copyright (C) 2014 Robin Burchell <robin.burchell@viroteck.net>
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtCore module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2014 Robin Burchell <robin.burchell@viroteck.net>
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
#ifndef QOSCBUNDLE_P_H
#define QOSCBUNDLE_P_H
#include "qoscmessage_p.h"
-#include <QtCore/QVector>
+#include <QtCore/QList>
QT_BEGIN_NAMESPACE
@@ -51,24 +15,24 @@ class QByteArray;
class QOscBundle
{
- QOscBundle(); // for QVector, don't use
- friend class QVector<QOscBundle>;
+ QOscBundle(); // for QList, don't use
+ friend class QList<QOscBundle>;
public:
explicit QOscBundle(const QByteArray &data);
bool isValid() const { return m_isValid; }
- QVector<QOscBundle> bundles() const { return m_bundles; }
- QVector<QOscMessage> messages() const { return m_messages; }
+ QList<QOscBundle> bundles() const { return m_bundles; }
+ QList<QOscMessage> messages() const { return m_messages; }
private:
bool m_isValid;
bool m_immediate;
quint32 m_timeEpoch;
quint32 m_timePico;
- QVector<QOscBundle> m_bundles;
- QVector<QOscMessage> m_messages;
+ QList<QOscBundle> m_bundles;
+ QList<QOscMessage> m_messages;
};
-Q_DECLARE_TYPEINFO(QOscBundle, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(QOscBundle, Q_RELOCATABLE_TYPE);
QT_END_NAMESPACE